@@ -31,7 +31,7 @@ def biomaj_version(options, config):
     Get biomaj version
     '''
     version = pkg_resources.require('biomaj')[0].version
-    tools = []
+    # tools = []
     biomaj_modules = [
         'biomaj',
         'biomaj-core',
@@ -234,15 +234,23 @@ def biomaj_search(options, config):
                 if prod['session'] == bank['current']:
                     iscurrent = "yes"
                 if options.json:
-                    results.append([b if b else '',
-                        prod['release'],
-                        prod['formats'],
-                        prod['types'], iscurrent])
+                    results.append(
+                        [
+                            b if b else '',
+                            prod['release'],
+                            prod['formats'],
+                            prod['types'], iscurrent
+                        ]
+                    )
                 else:
-                    results.append([b if b else '',
-                        prod['release'],
-                        ','.join(prod['formats']),
-                        ','.join(prod['types']), iscurrent])
+                    results.append(
+                        [
+                            b if b else '',
+                            prod['release'],
+                            ','.join(prod['formats']),
+                            ','.join(prod['types']), iscurrent
+                        ]
+                    )
         if options.json:
             return (True, {'matches': results, 'headers': headers})
 
@@ -433,6 +441,12 @@ def biomaj_whatsup(options, config):
             pending_len = 0
 
         whatsup.append(['queue', str(pending_len), 'waiting'])
+        for index in range(pending_len):
+            pending_action = redis_client.lindex(config['redis']['prefix'] + ':queue', index)
+            if pending_action:
+                pending_bank = json.loads(pending_action)
+                if pending_bank.get('bank', None):
+                    whatsup.append(['queued', pending_bank['bank'], 'waiting'])
 
     if not options.proxy:
         data_dir = BiomajConfig.global_config.get('GENERAL', 'data.dir')
@@ -466,7 +480,7 @@ def biomaj_whatsup(options, config):
 
 def biomaj_send_message(options, config):
     '''
-    Send message to rabbitmq listener
+    Send message to listener
     '''
     if not options.proxy:
         return (False, 'option not allowed without --proxy option')
@@ -751,9 +765,10 @@ def biomaj_update_status(options, config):
                 else:
                     msg.append([step, 'waiting'])
         if step in ['postprocess', 'preprocess', 'removeprocess']:
-            progress = status_info[step]['progress']
-            for proc in list(progress.keys()):
-                msg.append([proc, str(progress[proc])])
+            if status_info.get(step, None) and status_info[step].get('progress', None):
+                progress = status_info[step]['progress']
+                for proc in list(progress.keys()):
+                    msg.append([proc, str(progress[proc])])
     if options.json:
         return (True, {'pending': {'headers': pending_headers, 'actions': pending_actions}, 'status': {'headers': headers, 'process': msg}})
     else:
@@ -789,6 +804,7 @@ def biomaj_user_info(options, config):
         msg += 'Api key: ' + str(user['apikey']) + '\n'
     return (True, msg)
 
+
 def biomaj_stats(options, config):
     disk_stats = Bank.get_banks_disk_usage()
     results = []
@@ -810,6 +826,7 @@ def biomaj_stats(options, config):
         msg += tabulate(results, headers="firstrow", tablefmt="grid")
     return (True, msg)
 
+
 def biomaj_history(options, config):
     history = Bank.get_history(options.historyLimit)
     results = []
@@ -818,13 +835,16 @@ def biomaj_history(options, config):
         results.append(headers)
     msg = 'BioMAJ history\n'
     for h in history:
-        results.append([h['bank'],
-                        h['action'],
-                        datetime.datetime.utcfromtimestamp(h['start']),
-                        datetime.datetime.utcfromtimestamp(h['end']),
-                        str(h['updated']),
-                        str(h['error'])
-        ])
+        results.append(
+            [
+                h['bank'],
+                h['action'],
+                datetime.datetime.utcfromtimestamp(h['start']),
+                datetime.datetime.utcfromtimestamp(h['end']),
+                str(h['updated']),
+                str(h['error'])
+            ]
+        )
     if options.json:
         msg = {'headers': headers, 'history': results}
     else:
